@@ -1,5 +1,7 @@
 #pragma once
 
+#include <string>
+
 #include <morphio/morphology.h>
 #include <morphio/types.h>
 
@@ -9,7 +11,7 @@ namespace morphio {
 class GlialCell: public Morphology
 {
   public:
-    GlialCell(const std::string& source);
+    explicit GlialCell(const std::string& source);
 
   private:
     Soma soma() const;
