@@ -1,5 +1,8 @@
 #pragma once
 
+#include <cstdint>  // uint32_t
+#include <memory>   // std::shared_ptr
+
 #include <morphio/mitochondria.h>
 #include <morphio/properties.h>
 #include <morphio/section_base.h>
@@ -55,9 +58,14 @@ class MitoSection: public SectionBase<MitoSection>
      **/
     range<const floatType> relativePathLengths() const;
 
+    /**
+     * Return true if the both sections have the same neuriteSectionIds, diameters and relativePathLengths
+     */
+    bool hasSameShape(const MitoSection& other) const noexcept;
+
   protected:
-    MitoSection(uint32_t id_, const std::shared_ptr<Property::Properties>& morphology)
-        : SectionBase(id_, morphology) {}
+    MitoSection(uint32_t id, const std::shared_ptr<Property::Properties>& morphology)
+        : SectionBase(id, morphology) {}
     friend MitoSection Mitochondria::section(uint32_t) const;
     friend class SectionBase<MitoSection>;
     friend class mut::MitoSection;
