@@ -23,8 +23,7 @@ class Mitochondria
     using MitoSectionP = std::shared_ptr<MitoSection>;
 
   public:
-    Mitochondria()
-        : _counter(0) {}
+    Mitochondria() = default;
 
     const std::vector<MitoSectionP>& children(const MitoSectionP&) const;
     const MitoSectionP& section(uint32_t id) const;
@@ -101,20 +100,20 @@ class Mitochondria
 
     uint32_t _register(const MitoSectionP& section);
 
-    uint32_t _counter;
-    std::map<uint32_t, std::vector<MitoSectionP>> _children;
-    std::map<uint32_t, uint32_t> _parent;
-    std::vector<MitoSectionP> _rootSections;
-    std::map<uint32_t, MitoSectionP> _sections;
+    uint32_t _counter = 0;
+    std::map<uint32_t, std::vector<MitoSectionP>> children_;
+    std::map<uint32_t, uint32_t> parent_;
+    std::vector<MitoSectionP> root_sections_;
+    std::map<uint32_t, MitoSectionP> sections_;
 };
 
 inline const std::map<uint32_t, Mitochondria::MitoSectionP>& Mitochondria::sections() const
     noexcept {
-    return _sections;
+    return sections_;
 }
 
 inline const std::vector<Mitochondria::MitoSectionP>& Mitochondria::rootSections() const noexcept {
-    return _rootSections;
+    return root_sections_;
 }
 
 }  // namespace mut
