@@ -82,16 +82,27 @@ class Section: public SectionBase<Section>
      * Return the morphological type of this section (dendrite, axon, ...)
      */
     SectionType type() const;
+
+    /**
+     * Return true if the sections of the tree downstream (downstream = true) or upstream
+     * (donwstream = false) have the same section type as the current section.
+     */
+    bool isHeterogeneous(bool downstream = true) const;
+
+    /**
+     * Return true if the both sections have the same points, diameters and perimeters
+     */
+    bool hasSameShape(const Section& other) const noexcept;
+
     friend class mut::Section;
     friend Section Morphology::section(uint32_t) const;
     friend class SectionBase<Section>;
 
   protected:
-    Section(uint32_t id_, const std::shared_ptr<Property::Properties>& properties)
-        : SectionBase(id_, properties) {}
+    Section(uint32_t id, const std::shared_ptr<Property::Properties>& properties)
+        : SectionBase(id, properties) {}
 };
 
 }  // namespace morphio
 
 std::ostream& operator<<(std::ostream& os, const morphio::Section& section);
-std::ostream& operator<<(std::ostream& os, const morphio::range<const morphio::Point>& points);
