@@ -1,9 +1,21 @@
+import platform
+
+
+if platform.system() == "Windows":
+    # the plan is to leverage the h5py inclusion of hdf5 dll; this way
+    # there cannot be a mismatch between version, when using windows,
+    # and MorphIO doesn't need to build hdf5
+    import h5py as _h5py
+    assert (1, 12) == _h5py.version.hdf5_version_tuple[:2], f'1.12.x != {_h5py.version.hdf5_version}'
+    del _h5py
+
+
 from ._morphio import (
-    AccessMode,
     Annotation,
     AnnotationType,
     CellFamily,
     CellLevel,
+    DendriticSpine,
     EndoplasmicReticulum,
     GlialCell,
     IDSequenceError,
@@ -19,6 +31,7 @@ from ._morphio import (
     Option,
     PointLevel,
     Points,
+    PostSynapticDensity,
     Properties,
     RawDataError,
     Section,
