@@ -1,6 +1,4 @@
 #include <morphio/mito_section.h>
-#include <morphio/mitochondria.h>
-#include <morphio/morphology.h>
 
 namespace morphio {
 
@@ -40,4 +38,8 @@ range<const floatType> MitoSection::relativePathLengths() const {
     return get<Property::MitoPathLength>();
 }
 
+bool MitoSection::hasSameShape(const MitoSection& other) const noexcept {
+    return (other.neuriteSectionIds() == neuriteSectionIds() && other.diameters() == diameters() &&
+            other.relativePathLengths() == relativePathLengths());
+}
 }  // namespace morphio
