@@ -3,12 +3,12 @@
 
 namespace morphio {
 MitoSection Mitochondria::section(uint32_t id) const {
-    return {id, _properties};
+    return {id, properties_};
 }
 
 std::vector<MitoSection> Mitochondria::sections() const {
     std::vector<MitoSection> sections_;
-    for (unsigned int i = 0; i < _properties->get<morphio::Property::MitoSection>().size(); ++i) {
+    for (unsigned int i = 0; i < properties_->get<morphio::Property::MitoSection>().size(); ++i) {
         sections_.push_back(section(i));
     }
     return sections_;
@@ -16,7 +16,7 @@ std::vector<MitoSection> Mitochondria::sections() const {
 
 std::vector<MitoSection> Mitochondria::rootSections() const {
     std::vector<MitoSection> result;
-    const auto& mitoChildren = _properties->children<morphio::Property::MitoSection>();
+    const auto& mitoChildren = properties_->children<morphio::Property::MitoSection>();
     const auto& it = mitoChildren.find(-1);
     if (it != mitoChildren.end()) {
         const auto& children = it->second;
