@@ -1,7 +1,6 @@
 #include <queue>  // std::queue
 
 #include <morphio/mut/mitochondria.h>
-#include <morphio/mut/writers.h>
 
 
 #include "../shared_utils.hpp"
@@ -13,7 +12,7 @@ Mitochondria::MitoSectionP Mitochondria::appendRootSection(const morphio::MitoSe
                                                            bool recursive) {
     const auto ptr = std::make_shared<MitoSection>(this, _counter, section_);
     _register(ptr);
-    _rootSections.push_back(ptr);
+    root_sections_.push_back(ptr);
 
     if (recursive) {
         for (const auto& child : section_.children()) {
@@ -28,7 +27,7 @@ Mitochondria::MitoSectionP Mitochondria::appendRootSection(const MitoSectionP& s
                                                            bool recursive) {
     const auto section_copy = std::make_shared<MitoSection>(this, _counter, *section_);
     _register(section_copy);
-    _rootSections.push_back(section_copy);
+    root_sections_.push_back(section_copy);
 
     if (recursive) {
         for (const auto& child : section_->children()) {
@@ -43,7 +42,7 @@ Mitochondria::MitoSectionP Mitochondria::appendRootSection(
     const Property::MitochondriaPointLevel& pointProperties) {
     const auto ptr = std::make_shared<MitoSection>(this, _counter, pointProperties);
     _register(ptr);
-    _rootSections.push_back(ptr);
+    root_sections_.push_back(ptr);
 
     return ptr;
 }
@@ -58,16 +57,16 @@ static void _appendMitoProperties(Property::MitochondriaPointLevel& to,
 
 const std::vector<Mitochondria::MitoSectionP>& Mitochondria::children(
     const MitoSectionP& section_) const {
-    const auto it = _children.find(section_->id());
-    if (it == _children.end()) {
+    const auto it = children_.find(section_->id());
+    if (it == children_.end()) {
         static std::vector<Mitochondria::MitoSectionP> empty;
         return empty;
     }
     return it->second;
 }
 
-const Mitochondria::MitoSectionP& Mitochondria::parent(const MitoSectionP& parent_) const {
-    return section(_parent.at(parent_->id()));
+const Mitochondria::MitoSectionP& Mitochondria::parent(const MitoSectionP& parent) const {
+    return section(parent_.at(parent->id()));
 }
 
 bool Mitochondria::isRoot(const MitoSectionP& section_) const {
@@ -80,14 +79,14 @@ bool Mitochondria::isRoot(const MitoSectionP& section_) const {
 }
 
 const Mitochondria::MitoSectionP& Mitochondria::section(uint32_t id) const {
-    return _sections.at(id);
+    return sections_.at(id);
 }
 
 void Mitochondria::_buildMitochondria(Property::Properties& properties) const {
     int32_t counter = 0;
     std::map<uint32_t, int32_t> newIds;
 
-    for (std::shared_ptr<MitoSection> mitoStart : _rootSections) {
+    for (std::shared_ptr<MitoSection> mitoStart : root_sections_) {
         std::queue<std::shared_ptr<MitoSection>> q;
         q.push(mitoStart);
         while (!q.empty()) {
@@ -103,47 +102,49 @@ void Mitochondria::_buildMitochondria(Property::Properties& properties) const {
 
             newIds[section_->id()] = counter++;
 
-            for (auto child : children(section_))
+            for (auto child : children(section_)) {
                 q.push(child);
+            }
         }
     }
 }
 
-const std::shared_ptr<MitoSection>& Mitochondria::mitoSection(uint32_t id_) const {
-    return _sections.at(id_);
+const std::shared_ptr<MitoSection>& Mitochondria::mitoSection(uint32_t id) const {
+    return sections_.at(id);
 }
 
-mito_depth_iterator Mitochondria::depth_begin(const MitoSectionP& section_) const {
-    return mito_depth_iterator(section_);
+mito_depth_iterator Mitochondria::depth_begin(const MitoSectionP& section) const {
+    return mito_depth_iterator(section);
 }
 
 mito_depth_iterator Mitochondria::depth_end() const {
     return mito_depth_iterator();
 }
 
-mito_breadth_iterator Mitochondria::breadth_begin(const MitoSectionP& section_) const {
-    return mito_breadth_iterator(section_);
+mito_breadth_iterator Mitochondria::breadth_begin(const MitoSectionP& section) const {
+    return mito_breadth_iterator(section);
 }
 
 mito_breadth_iterator Mitochondria::breadth_end() const {
     return mito_breadth_iterator();
 }
 
-mito_upstream_iterator Mitochondria::upstream_begin(const MitoSectionP& section_) const {
-    return mito_upstream_iterator(section_);
+mito_upstream_iterator Mitochondria::upstream_begin(const MitoSectionP& section) const {
+    return mito_upstream_iterator(section);
 }
 
 mito_upstream_iterator Mitochondria::upstream_end() const {
     return mito_upstream_iterator();
 }
 
-uint32_t Mitochondria::_register(const MitoSectionP& section_) {
-    if (_sections.count(section_->id()))
+uint32_t Mitochondria::_register(const MitoSectionP& section) {
+    if (sections_.count(section->id())) {
         throw SectionBuilderError("Section already exists");
-    _counter = std::max(_counter, section_->id()) + 1;
+    }
+    _counter = std::max(_counter, section->id()) + 1;
 
-    _sections[section_->id()] = section_;
-    return section_->id();
+    sections_[section->id()] = section;
+    return section->id();
 }
 
 }  // namespace mut
