@@ -1,16 +1,15 @@
-#include <assert.h>
-
+#include <cassert>
+#include <cctype>  // std::tolower
 #include <sstream>
 #include <string>
 
 #include <morphio/endoplasmic_reticulum.h>
-#include <morphio/mito_section.h>
 #include <morphio/mitochondria.h>
+#include <morphio/mut/endoplasmic_reticulum.h>
 #include <morphio/mut/morphology.h>
 #include <morphio/mut/section.h>
 #include <morphio/mut/writers.h>
 #include <morphio/soma.h>
-#include <morphio/tools.h>
 
 #include "../shared_utils.hpp"
 
@@ -24,8 +23,7 @@ Morphology::Morphology(const std::string& uri, unsigned int options)
     : Morphology(morphio::Morphology(uri, options)) {}
 
 Morphology::Morphology(const morphio::mut::Morphology& morphology, unsigned int options)
-    : _counter(0)
-    , _soma(std::make_shared<Soma>(*morphology.soma()))
+    : _soma(std::make_shared<Soma>(*morphology.soma()))
     , _cellProperties(std::make_shared<morphio::Property::CellLevel>(*morphology._cellProperties))
     , _endoplasmicReticulum(morphology.endoplasmicReticulum())
     , _dendriticSpineLevel(morphology._dendriticSpineLevel) {
@@ -41,12 +39,11 @@ Morphology::Morphology(const morphio::mut::Morphology& morphology, unsigned int
 }
 
 Morphology::Morphology(const morphio::Morphology& morphology, unsigned int options)
-    : _counter(0)
-    , _soma(std::make_shared<Soma>(morphology.soma()))
+    : _soma(std::make_shared<Soma>(morphology.soma()))
     , _cellProperties(
-          std::make_shared<morphio::Property::CellLevel>(morphology._properties->_cellLevel))
+          std::make_shared<morphio::Property::CellLevel>(morphology.properties_->_cellLevel))
     , _endoplasmicReticulum(morphology.endoplasmicReticulum())
-    , _dendriticSpineLevel(morphology._properties->_dendriticSpineLevel) {
+    , _dendriticSpineLevel(morphology.properties_->_dendriticSpineLevel) {
     for (const morphio::Section& root : morphology.rootSections()) {
         appendRootSection(root, true);
     }
@@ -88,13 +85,14 @@ bool _checkDuplicatePoint(const std::shared_ptr<Section>& parent,
 
 std::shared_ptr<Section> Morphology::appendRootSection(const morphio::Section& section_,
                                                        bool recursive) {
-    const std::shared_ptr<Section> ptr(new Section(this, _counter, section_));
+    std::shared_ptr<Section> ptr(new Section(this, _counter, section_));
     _register(ptr);
     _rootSections.push_back(ptr);
 
     const bool emptySection = ptr->points().empty();
-    if (emptySection)
+    if (emptySection) {
         printError(Warning::APPENDING_EMPTY_SECTION, _err.WARNING_APPENDING_EMPTY_SECTION(ptr));
+    }
 
     if (recursive) {
         for (const auto& child : section_.children()) {
@@ -107,13 +105,14 @@ std::shared_ptr<Section> Morphology::appendRootSection(const morphio::Section& s
 
 std::shared_ptr<Section> Morphology::appendRootSection(const std::shared_ptr<Section>& section_,
                                                        bool recursive) {
-    const std::shared_ptr<Section> section_copy(new Section(this, _counter, *section_));
+    std::shared_ptr<Section> section_copy(new Section(this, _counter, *section_));
     _register(section_copy);
     _rootSections.push_back(section_copy);
     const bool emptySection = section_copy->points().empty();
-    if (emptySection)
+    if (emptySection) {
         printError(Warning::APPENDING_EMPTY_SECTION,
                    _err.WARNING_APPENDING_EMPTY_SECTION(section_copy));
+    }
 
     if (recursive) {
         for (const auto& child : section_->children()) {
@@ -126,20 +125,22 @@ std::shared_ptr<Section> Morphology::appendRootSection(const std::shared_ptr<Sec
 
 std::shared_ptr<Section> Morphology::appendRootSection(const Property::PointLevel& pointProperties,
                                                        SectionType type) {
-    const std::shared_ptr<Section> ptr(new Section(this, _counter, type, pointProperties));
+    std::shared_ptr<Section> ptr(new Section(this, _counter, type, pointProperties));
     _register(ptr);
     _rootSections.push_back(ptr);
 
     bool emptySection = ptr->points().empty();
-    if (emptySection)
+    if (emptySection) {
         printError(Warning::APPENDING_EMPTY_SECTION, _err.WARNING_APPENDING_EMPTY_SECTION(ptr));
+    }
 
     return ptr;
 }
 
 uint32_t Morphology::_register(const std::shared_ptr<Section>& section_) {
-    if (_sections.count(section_->id()))
+    if (_sections.count(section_->id())) {
         throw SectionBuilderError("Section already exists");
+    }
     _counter = std::max(_counter, section_->id()) + 1;
     _sections[section_->id()] = section_;
     return section_->id();
@@ -154,16 +155,17 @@ Morphology::~Morphology() {
 
 void Morphology::eraseByValue(std::vector<std::shared_ptr<Section>>& vec,
                               const std::shared_ptr<Section> section) {
-    if (section->_morphology == this) {
-        section->_morphology = nullptr;
-        section->_id = 0xffffffff;
+    if (section->morphology_ == this) {
+        section->morphology_ = nullptr;
+        section->id_ = 0xffffffff;
     }
     vec.erase(std::remove(vec.begin(), vec.end(), section), vec.end());
 }
 
 void Morphology::deleteSection(std::shared_ptr<Section> section_, bool recursive) {
-    if (!section_)
+    if (!section_) {
         return;
+    }
 
     unsigned int id = section_->id();
 
@@ -201,8 +203,9 @@ void _appendProperties(Property::PointLevel& to, const Property::PointLevel& fro
     _appendVector(to._points, from._points, offset);
     _appendVector(to._diameters, from._diameters, offset);
 
-    if (!from._perimeters.empty())
+    if (!from._perimeters.empty()) {
         _appendVector(to._perimeters, from._perimeters, offset);
+    }
 }
 
 void Morphology::removeUnifurcations() {
@@ -220,15 +223,17 @@ void Morphology::removeUnifurcations(const morphio::readers::DebugInfo& debugInf
         ++it;
         unsigned int sectionId = section_->id();
 
-        if (section_->isRoot())
+        if (section_->isRoot()) {
             continue;
+        }
 
         unsigned int parentId = section_->parent()->id();
 
         if (!ErrorMessages::isIgnored(Warning::WRONG_DUPLICATE) &&
-            !_checkDuplicatePoint(section_->parent(), section_))
+            !_checkDuplicatePoint(section_->parent(), section_)) {
             printError(Warning::WRONG_DUPLICATE,
                        err.WARNING_WRONG_DUPLICATE(section_, section_->parent()));
+        }
 
         auto parent = section_->parent();
         bool isUnifurcation = parent->children().size() == 1;
@@ -249,10 +254,11 @@ void Morphology::removeUnifurcations(const morphio::readers::DebugInfo& debugInf
 
             morphio::_appendVector(parent->diameters(), section_->diameters(), duplicate ? 1 : 0);
 
-            if (!parent->perimeters().empty())
+            if (!parent->perimeters().empty()) {
                 morphio::_appendVector(parent->perimeters(),
                                        section_->perimeters(),
                                        duplicate ? 1 : 0);
+            }
 
             deleteSection(section_, false);
         }
@@ -262,8 +268,9 @@ void Morphology::removeUnifurcations(const morphio::readers::DebugInfo& debugInf
 void Morphology::_raiseIfUnifurcations() {
     for (auto it = depth_begin(); it != depth_end(); ++it) {
         std::shared_ptr<Section> section_ = *it;
-        if (section_->isRoot())
+        if (section_->isRoot()) {
             continue;
+        }
 
         unsigned int parentId = section_->parent()->id();
 
@@ -283,18 +290,18 @@ Property::Properties Morphology::buildReadOnly() const {
 
     properties._cellLevel = *_cellProperties;
     properties._cellLevel._somaType = _soma->type();
-    _appendProperties(properties._somaLevel, _soma->_pointProperties);
+    _appendProperties(properties._somaLevel, _soma->point_properties_);
 
     for (auto it = depth_begin(); it != depth_end(); ++it) {
-        const std::shared_ptr<Section>& section_ = *it;
-        unsigned int sectionId = section_->id();
-        int parentOnDisk = (section_->isRoot() ? -1 : newIds[section_->parent()->id()]);
+        const std::shared_ptr<Section>& section = *it;
+        unsigned int sectionId = section->id();
+        int parentOnDisk = (section->isRoot() ? -1 : newIds[section->parent()->id()]);
 
         auto start = static_cast<int>(properties._pointLevel._points.size());
         properties._sectionLevel._sections.push_back({start, parentOnDisk});
-        properties._sectionLevel._sectionTypes.push_back(section_->type());
+        properties._sectionLevel._sectionTypes.push_back(section->type());
         newIds[sectionId] = sectionIdOnDisk++;
-        _appendProperties(properties._pointLevel, section_->_pointProperties);
+        _appendProperties(properties._pointLevel, section->point_properties_);
     }
 
     mitochondria()._buildMitochondria(properties);
@@ -321,21 +328,26 @@ breadth_iterator Morphology::breadth_end() const {
 }
 
 void Morphology::applyModifiers(unsigned int modifierFlags) {
-    if (modifierFlags & NO_DUPLICATES & TWO_POINTS_SECTIONS)
+    if (modifierFlags & NO_DUPLICATES & TWO_POINTS_SECTIONS) {
         throw SectionBuilderError(
             _err.ERROR_UNCOMPATIBLE_FLAGS(NO_DUPLICATES, TWO_POINTS_SECTIONS));
+    }
 
-    if (modifierFlags & SOMA_SPHERE)
+    if (modifierFlags & SOMA_SPHERE) {
         modifiers::soma_sphere(*this);
+    }
 
-    if (modifierFlags & NO_DUPLICATES)
+    if (modifierFlags & NO_DUPLICATES) {
         modifiers::no_duplicate_point(*this);
+    }
 
-    if (modifierFlags & TWO_POINTS_SECTIONS)
+    if (modifierFlags & TWO_POINTS_SECTIONS) {
         modifiers::two_points_sections(*this);
+    }
 
-    if (modifierFlags & NRN_ORDER)
+    if (modifierFlags & NRN_ORDER) {
         modifiers::nrn_order(*this);
+    }
 }
 
 std::unordered_map<int, std::vector<unsigned int>> Morphology::connectivity() {
@@ -360,7 +372,6 @@ std::unordered_map<int, std::vector<unsigned int>> Morphology::connectivity() {
     return connectivity;
 }
 
-
 void Morphology::write(const std::string& filename) {
     const size_t pos = filename.find_last_of(".");
     assert(pos != std::string::npos);
@@ -368,22 +379,25 @@ void Morphology::write(const std::string& filename) {
     std::string extension;
 
     for (const auto& root : rootSections()) {
-        if (root->points().size() < 2)
+        if (root->points().size() < 2) {
             throw morphio::SectionBuilderError("Root sections must have at least 2 points");
+        }
     }
 
-    for (char c : filename.substr(pos))
-        extension += my_tolower(c);
+    for (char c : filename.substr(pos)) {
+        extension += static_cast<char>(std::tolower(static_cast<unsigned char>(c)));
+    }
 
-    if (extension == ".h5")
+    if (extension == ".h5") {
         writer::h5(*this, filename);
-    else if (extension == ".asc")
+    } else if (extension == ".asc") {
         writer::asc(*this, filename);
-    else if (extension == ".swc") {
+    } else if (extension == ".swc") {
         _raiseIfUnifurcations();
         writer::swc(*this, filename);
-    } else
+    } else {
         throw UnknownFileType(_err.ERROR_WRONG_EXTENSION(filename));
+    }
 }
 
 }  // end namespace mut
