@@ -132,8 +132,14 @@ class SWCBuilder
         if (somata.size() > 1)
             throw morphio::SomaError(err.ERROR_MULTIPLE_SOMATA(somata));
 
-        if (somata.empty())
+        if (somata.empty()) {
             printError(Warning::NO_SOMA_FOUND, err.WARNING_NO_SOMA_FOUND());
+        } else {
+            for (const auto& sample_pair : samples) {
+                const auto& sample = sample_pair.second;
+                warnIfDisconnectedNeurite(sample);
+            }
+        }
     }
 
     void raiseIfNoParent(const Sample& sample) {
@@ -141,6 +147,11 @@ class SWCBuilder
             throw morphio::MissingParentError(err.ERROR_MISSING_PARENT(sample));
     }
 
+    void warnIfZeroDiameter(const Sample& sample) {
+        if (sample.diameter < morphio::epsilon)
+            printError(Warning::ZERO_DIAMETER, err.WARNING_ZERO_DIAMETER(sample));
+    }
+
     /**
        A neurite which is not attached to the soma
     **/
@@ -189,7 +200,7 @@ class SWCBuilder
         raiseIfSelfParent(sample);
         raiseIfBrokenSoma(sample);
         raiseIfNoParent(sample);
-        warnIfDisconnectedNeurite(sample);
+        warnIfZeroDiameter(sample);
     }
 
     void _checkNeuroMorphoSoma(const Sample& root, const std::vector<Sample>& _children) {
@@ -232,7 +243,7 @@ class SWCBuilder
             return SOMA_SINGLE_POINT;
         }
         case 2: {
-            return SOMA_UNDEFINED;
+            return SOMA_CYLINDERS;
         }
         // NeuroMorpho format is characterized by a 3 points soma
         // with a bifurcation at soma root
