@@ -1,66 +1,75 @@
 #include <algorithm>  // std::max
 #include <cmath>      // std::sqrt
 #include <numeric>    // std::accumulate
+#include <sstream>    // ostringstream
 #include <string>     // std::string
-#include <cctype>     // std::tolower
 
 #include <morphio/types.h>
 
 namespace morphio {
 Point operator+(const Point& left, const Point& right) {
     Point ret;
-    for (size_t i = 0; i < ret.size(); ++i)
+    for (size_t i = 0; i < ret.size(); ++i) {
         ret[i] = left[i] + right[i];
+    }
     return ret;
 }
 
 Point operator-(const Point& left, const Point& right) {
     Point ret;
-    for (size_t i = 0; i < ret.size(); ++i)
+    for (size_t i = 0; i < ret.size(); ++i) {
         ret[i] = left[i] - right[i];
+    }
     return ret;
 }
 
 Point operator+=(Point& left, const Point& right) {
-    for (size_t i = 0; i < left.size(); ++i)
+    for (size_t i = 0; i < left.size(); ++i) {
         left[i] += right[i];
+    }
     return left;
 }
 
 Point operator-=(Point& left, const Point& right) {
-    for (size_t i = 0; i < left.size(); ++i)
+    for (size_t i = 0; i < left.size(); ++i) {
         left[i] -= right[i];
+    }
     return left;
 }
 
 Point operator/=(Point& left, floatType factor) {
-    for (size_t i = 0; i < left.size(); ++i)
+    for (size_t i = 0; i < left.size(); ++i) {
         left[i] /= factor;
+    }
     return left;
 }
 
 Points operator+(const Points& points, const Point& right) {
     Points result;
-    for (auto& p : points)
+    for (auto& p : points) {
         result.push_back(p + right);
+    }
     return result;
 }
 Points operator-(const Points& points, const Point& right) {
     Points result;
-    for (auto& p : points)
+    for (auto& p : points) {
         result.push_back(p - right);
+    }
     return result;
 }
 
 Points operator+=(Points& points, const Point& right) {
-    for (auto& p : points)
+    for (auto& p : points) {
         p += right;
+    }
     return points;
 }
 
 Points operator-=(Points& points, const Point& right) {
-    for (auto& p : points)
+    for (auto& p : points) {
         p -= right;
+    }
     return points;
 }
 
@@ -87,16 +96,26 @@ std::string dumpPoints(const Points& points) {
     return oss.str();
 }
 
+std::string dumpPoints(const morphio::range<const morphio::Point>& points) {
+    std::ostringstream oss;
+    for (const auto& point : points) {
+        oss << dumpPoint(point) << '\n';
+    }
+    return oss.str();
+}
+
 template <typename T>
 Point centerOfGravity(const T& points) {
-    Point::value_type x = 0, y = 0, z = 0;
-    const auto size = static_cast<Point::value_type>(points.size());
+    Point::value_type x = 0;
+    Point::value_type y = 0;
+    Point::value_type z = 0;
+    const auto count = static_cast<Point::value_type>(points.size());
     for (const auto& point : points) {
         x += point[0];
         y += point[1];
         z += point[2];
     }
-    return Point({x / size, y / size, z / size});
+    return Point({x / count, y / count, z / count});
 }
 template Point centerOfGravity(const range<const Point>& points);
 template Point centerOfGravity(const Points& points);
@@ -107,7 +126,7 @@ floatType maxDistanceToCenterOfGravity(const T& points) {
     return std::accumulate(std::begin(points),
                            std::end(points),
                            floatType{0},
-                           [&](morphio::floatType a, const Point& b) {
+                           [&](floatType a, const Point& b) {
                                return std::max(a, distance(c, b));
                            });
 }
@@ -122,40 +141,32 @@ Point operator*(const Point& from, T factor) {
     return ret;
 }
 template Point operator*<int>(const Point& from, int factor);
-template Point operator*<morphio::floatType>(const Point& from, floatType factor);
+template Point operator*<floatType>(const Point& from, floatType factor);
 
 template <typename T>
 Point operator*(T factor, const Point& from) {
     return from * factor;
 }
 template Point operator*<int>(int factor, const Point& from);
-template Point operator*<morphio::floatType>(morphio::floatType factor, const Point& from);
+template Point operator*<floatType>(floatType factor, const Point& from);
 
 template <typename T>
 Point operator/(const Point& from, T factor) {
-    return from * (1 / static_cast<morphio::floatType>(factor));
+    return from * (1 / static_cast<floatType>(factor));
 }
 template Point operator/(const Point& from, int factor);
 template Point operator/(const Point& from, floatType factor);
 
-std::ostream& operator<<(std::ostream& os, const Points& points) {
-    return os << morphio::dumpPoints(points);
-}
+}  // namespace morphio
 
 std::ostream& operator<<(std::ostream& os, const morphio::Point& point) {
     return os << morphio::dumpPoint(point);
 }
 
-// Like std::tolower but accepts char
-char my_tolower(char ch) {
-    return static_cast<char>(std::tolower(static_cast<unsigned char>(ch)));
-}
-
-}  // namespace morphio
-
 std::ostream& operator<<(std::ostream& os, const morphio::Points& points) {
     return os << morphio::dumpPoints(points);
 }
-std::ostream& operator<<(std::ostream& os, const morphio::Point& point) {
-    return os << morphio::dumpPoint(point);
+
+std::ostream& operator<<(std::ostream& os, const morphio::range<const morphio::Point>& points) {
+    return os << morphio::dumpPoints(points);
 }
